Class: Dataleon::Client
- Inherits:
-
Internal::Transport::BaseClient
- Object
- Internal::Transport::BaseClient
- Dataleon::Client
- Defined in:
- lib/dataleon/client.rb
Constant Summary collapse
- DEFAULT_MAX_RETRIES =
Default max number of retries to attempt after a failed retryable request.
2- DEFAULT_TIMEOUT_IN_SECONDS =
Default per-request timeout.
60.0- DEFAULT_INITIAL_RETRY_DELAY =
Default initial retry delay in seconds. Overall delay is calculated using exponential backoff + jitter.
0.5- DEFAULT_MAX_RETRY_DELAY =
Default max retry delay in seconds.
8.0
Constants inherited from Internal::Transport::BaseClient
Internal::Transport::BaseClient::MAX_REDIRECTS, Internal::Transport::BaseClient::PLATFORM_HEADERS
Instance Attribute Summary collapse
-
#api_key ⇒ String
readonly
API key needed to authorize requests.
- #companies ⇒ Dataleon::Resources::Companies readonly
- #individuals ⇒ Dataleon::Resources::Individuals readonly
Attributes inherited from Internal::Transport::BaseClient
#base_url, #headers, #idempotency_header, #initial_retry_delay, #max_retries, #max_retry_delay, #requester, #timeout
Instance Method Summary collapse
-
#initialize(api_key: ENV["DATALEON_API_KEY"], base_url: ENV["DATALEON_BASE_URL"], max_retries: self.class::DEFAULT_MAX_RETRIES, timeout: self.class::DEFAULT_TIMEOUT_IN_SECONDS, initial_retry_delay: self.class::DEFAULT_INITIAL_RETRY_DELAY, max_retry_delay: self.class::DEFAULT_MAX_RETRY_DELAY) ⇒ Client
constructor
Creates and returns a new client for interacting with the API.
Methods inherited from Internal::Transport::BaseClient
follow_redirect, #inspect, reap_connection!, #request, #send_request, should_retry?, validate!
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(api_key: ENV["DATALEON_API_KEY"], base_url: ENV["DATALEON_BASE_URL"], max_retries: self.class::DEFAULT_MAX_RETRIES, timeout: self.class::DEFAULT_TIMEOUT_IN_SECONDS, initial_retry_delay: self.class::DEFAULT_INITIAL_RETRY_DELAY, max_retry_delay: self.class::DEFAULT_MAX_RETRY_DELAY) ⇒ Client
Creates and returns a new client for interacting with the API.
‘Api-Key` header. Get your API key from the Dataleon dashboard. Defaults to `ENV`
‘“api.example.com/v2/”`. Defaults to `ENV`
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/dataleon/client.rb', line 52 def initialize( api_key: ENV["DATALEON_API_KEY"], base_url: ENV["DATALEON_BASE_URL"], max_retries: self.class::DEFAULT_MAX_RETRIES, timeout: self.class::DEFAULT_TIMEOUT_IN_SECONDS, initial_retry_delay: self.class::DEFAULT_INITIAL_RETRY_DELAY, max_retry_delay: self.class::DEFAULT_MAX_RETRY_DELAY ) base_url ||= "https://inference.eu-west-1.dataleon.ai" if api_key.nil? raise ArgumentError.new("api_key is required, and can be set via environ: \"DATALEON_API_KEY\"") end @api_key = api_key.to_s super( base_url: base_url, timeout: timeout, max_retries: max_retries, initial_retry_delay: initial_retry_delay, max_retry_delay: max_retry_delay ) @individuals = Dataleon::Resources::Individuals.new(client: self) @companies = Dataleon::Resources::Companies.new(client: self) end |
Instance Attribute Details
#api_key ⇒ String (readonly)
API key needed to authorize requests. You must provide a valid API key in the ‘Api-Key` header. Get your API key from the Dataleon dashboard.
21 22 23 |
# File 'lib/dataleon/client.rb', line 21 def api_key @api_key end |
#companies ⇒ Dataleon::Resources::Companies (readonly)
27 28 29 |
# File 'lib/dataleon/client.rb', line 27 def companies @companies end |
#individuals ⇒ Dataleon::Resources::Individuals (readonly)
24 25 26 |
# File 'lib/dataleon/client.rb', line 24 def individuals @individuals end |