Class: Dataleon::Models::Check

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dataleon/models/check.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(masked: nil, message: nil, name: nil, validate: nil, weight: nil) ⇒ Object

Represents a verification check result.

Parameters:

  • masked (Boolean) (defaults to: nil)

    Indicates whether the result or data is masked/hidden.

  • message (String) (defaults to: nil)

    Additional message or explanation about the check result.

  • name (String) (defaults to: nil)

    Name or type of the check performed.

  • validate (Boolean) (defaults to: nil)

    Result of the check, true if passed.

  • weight (Integer) (defaults to: nil)

    Importance or weight of the check, often used in scoring.



# File 'lib/dataleon/models/check.rb', line 36

Instance Attribute Details

#maskedBoolean?

Indicates whether the result or data is masked/hidden.

Returns:

  • (Boolean, nil)


10
# File 'lib/dataleon/models/check.rb', line 10

optional :masked, Dataleon::Internal::Type::Boolean

#messageString?

Additional message or explanation about the check result.

Returns:

  • (String, nil)


16
# File 'lib/dataleon/models/check.rb', line 16

optional :message, String

#nameString?

Name or type of the check performed.

Returns:

  • (String, nil)


22
# File 'lib/dataleon/models/check.rb', line 22

optional :name, String

#validateBoolean?

Result of the check, true if passed.

Returns:

  • (Boolean, nil)


28
# File 'lib/dataleon/models/check.rb', line 28

optional :validate, Dataleon::Internal::Type::Boolean

#weightInteger?

Importance or weight of the check, often used in scoring.

Returns:

  • (Integer, nil)


34
# File 'lib/dataleon/models/check.rb', line 34

optional :weight, Integer