Class: Dataleon::Models::CompanyCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/dataleon/models/company_create_params.rb

Overview

Defined Under Namespace

Classes: Company, TechnicalData

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, address: nil, commercial_name: nil, country: nil, email: nil, employer_identification_number: nil, legal_form: nil, phone_number: nil, registration_date: nil, registration_id: nil, share_capital: nil, status: nil, tax_identification_number: nil, type: nil, website_url: nil) ⇒ Object

Some parameter documentations has been truncated, see Company for more details.

Main information about the company being registered.

Parameters:

  • name (String)

    Legal name of the company.

  • address (String) (defaults to: nil)

    Registered address of the company.

  • commercial_name (String) (defaults to: nil)

    Commercial or trade name of the company, if different from the legal name.

  • country (String) (defaults to: nil)

    ISO 3166-1 alpha-2 country code of company registration (e.g., “FR” for France).

  • email (String) (defaults to: nil)

    Contact email address for the company.

  • employer_identification_number (String) (defaults to: nil)

    Employer Identification Number (EIN) or equivalent.

  • legal_form (String) (defaults to: nil)

    Legal structure of the company (e.g., SARL, SAS).

  • phone_number (String) (defaults to: nil)

    Contact phone number for the company.

  • registration_date (String) (defaults to: nil)

    Date of official company registration in YYYY-MM-DD format.

  • registration_id (String) (defaults to: nil)

    Official company registration identifier.

  • share_capital (String) (defaults to: nil)

    Declared share capital of the company, usually in euros.

  • status (String) (defaults to: nil)

    Current status of the company (e.g., active, inactive).

  • tax_identification_number (String) (defaults to: nil)

    National tax identifier (e.g., VAT or TIN).

  • type (String) (defaults to: nil)

    Type of company, such as “main” or “affiliated”.

  • website_url (String) (defaults to: nil)

    Company’s official website URL.



# File 'lib/dataleon/models/company_create_params.rb', line 140

Instance Attribute Details

#companyDataleon::Models::CompanyCreateParams::Company

Main information about the company being registered.



14
# File 'lib/dataleon/models/company_create_params.rb', line 14

required :company, -> { Dataleon::CompanyCreateParams::Company }

#source_idString?

Optional identifier to track the origin of the request or integration from your system.

Returns:

  • (String, nil)


27
# File 'lib/dataleon/models/company_create_params.rb', line 27

optional :source_id, String

#technical_dataDataleon::Models::CompanyCreateParams::TechnicalData?

Technical metadata and callback configuration.



33
# File 'lib/dataleon/models/company_create_params.rb', line 33

optional :technical_data, -> { Dataleon::CompanyCreateParams::TechnicalData }

#workspace_idString

Unique identifier of the workspace in which the company is being created.

Returns:

  • (String)


20
# File 'lib/dataleon/models/company_create_params.rb', line 20

required :workspace_id, String