Module: Dataleon::Models::CompanyCreateParams::TechnicalData::PortalStep

Extended by:
Internal::Type::Enum
Defined in:
lib/dataleon/models/company_create_params.rb

Constant Summary collapse

IDENTITY_VERIFICATION =
:identity_verification
DOCUMENT_SIGNING =
:document_signing
PROOF_OF_ADDRESS =
:proof_of_address
SELFIE =
:selfie
FACE_MATCH =
:face_match

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/dataleon/models/company_create_params.rb', line 252

Instance Method Details

#initialize(active_aml_suspicions: nil, callback_url: nil, callback_url_notification: nil, filtering_score_aml_suspicions: nil, language: nil, portal_steps: nil, raw_data: nil) ⇒ Object

Some parameter documentations has been truncated, see Dataleon::Models::CompanyCreateParams::TechnicalData for more details.

Technical metadata and callback configuration.

Parameters:

  • active_aml_suspicions (Boolean) (defaults to: nil)

    Flag indicating whether there are active research AML (Anti-Money Laundering) su

  • callback_url (String) (defaults to: nil)

    URL to receive a callback once the company is processed.

  • callback_url_notification (String) (defaults to: nil)

    URL to receive notifications about the processing state and status.

  • filtering_score_aml_suspicions (Float) (defaults to: nil)

    Minimum filtering score (between 0 and 1) for AML suspicions to be considered.

  • language (String) (defaults to: nil)

    Preferred language for responses or notifications (e.g., “eng”, “fra”).

  • portal_steps (Array<Symbol, Dataleon::Models::CompanyCreateParams::TechnicalData::PortalStep>) (defaults to: nil)

    List of steps to include in the portal workflow.

  • raw_data (Boolean) (defaults to: nil)

    Flag indicating whether to include raw data in the response.



243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/dataleon/models/company_create_params.rb', line 243

module PortalStep
  extend Dataleon::Internal::Type::Enum

  IDENTITY_VERIFICATION = :identity_verification
  DOCUMENT_SIGNING = :document_signing
  PROOF_OF_ADDRESS = :proof_of_address
  SELFIE = :selfie
  FACE_MATCH = :face_match

  # @!method self.values
  #   @return [Array<Symbol>]
end