Class: Dataleon::Models::CompanyRegistration::Company

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dataleon/models/company_registration.rb

Overview

See Also:

Defined Under Namespace

Classes: Contact

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(address: nil, closure_date: nil, commercial_name: nil, contact: nil, country: nil, email: nil, employees: nil, employer_identification_number: nil, insolvency_exists: nil, insolvency_ongoing: nil, legal_form: nil, name: nil, phone_number: nil, registration_date: nil, registration_id: nil, share_capital: nil, status: nil, tax_identification_number: nil, type: nil, website_url: nil) ⇒ Object

Some parameter documentations has been truncated, see Dataleon::Models::CompanyRegistration::Company for more details.

Main information about the company being registered, including legal name, registration ID, and address.

Parameters:

  • address (String) (defaults to: nil)

    Full registered address of the company.

  • closure_date (Date) (defaults to: nil)

    Closure date of the company, if applicable.

  • commercial_name (String) (defaults to: nil)

    Trade or commercial name of the company.

  • contact (Dataleon::Models::CompanyRegistration::Company::Contact) (defaults to: nil)

    Contact information for the company, including email, phone number, and address.

  • country (String) (defaults to: nil)

    Country code where the company is registered.

  • email (String) (defaults to: nil)

    Contact email address for the company.

  • employees (Integer) (defaults to: nil)

    Number of employees in the company.

  • employer_identification_number (String) (defaults to: nil)

    Employer Identification Number (EIN) or equivalent.

  • insolvency_exists (Boolean) (defaults to: nil)

    Indicates whether an insolvency procedure exists for the company.

  • insolvency_ongoing (Boolean) (defaults to: nil)

    Indicates whether an insolvency procedure is ongoing for the company.

  • legal_form (String) (defaults to: nil)

    Legal form or structure of the company (e.g., LLC, SARL).

  • name (String) (defaults to: nil)

    Legal registered name of the company.

  • phone_number (String) (defaults to: nil)

    Contact phone number for the company, including country code.

  • registration_date (Date) (defaults to: nil)

    Date when the company was officially registered.

  • registration_id (String) (defaults to: nil)

    Official company registration number or ID.

  • share_capital (String) (defaults to: nil)

    Total share capital of the company, including currency.

  • status (String) (defaults to: nil)

    Current status of the company (e.g., active, inactive).

  • tax_identification_number (String) (defaults to: nil)

    Tax identification number for the company.

  • type (String) (defaults to: nil)

    Type of company within the workspace, e.g., main or affiliated.

  • website_url (String) (defaults to: nil)

    Official website URL of the company.



# File 'lib/dataleon/models/company_registration.rb', line 390

Instance Attribute Details

#addressString?

Full registered address of the company.

Returns:

  • (String, nil)


274
# File 'lib/dataleon/models/company_registration.rb', line 274

optional :address, String

#closure_dateDate?

Closure date of the company, if applicable.

Returns:

  • (Date, nil)


280
# File 'lib/dataleon/models/company_registration.rb', line 280

optional :closure_date, Date

#commercial_nameString?

Trade or commercial name of the company.

Returns:

  • (String, nil)


286
# File 'lib/dataleon/models/company_registration.rb', line 286

optional :commercial_name, String

#contactDataleon::Models::CompanyRegistration::Company::Contact?

Contact information for the company, including email, phone number, and address.



292
# File 'lib/dataleon/models/company_registration.rb', line 292

optional :contact, -> { Dataleon::CompanyRegistration::Company::Contact }

#countryString?

Country code where the company is registered.

Returns:

  • (String, nil)


298
# File 'lib/dataleon/models/company_registration.rb', line 298

optional :country, String

#emailString?

Contact email address for the company.

Returns:

  • (String, nil)


304
# File 'lib/dataleon/models/company_registration.rb', line 304

optional :email, String

#employeesInteger?

Number of employees in the company.

Returns:

  • (Integer, nil)


310
# File 'lib/dataleon/models/company_registration.rb', line 310

optional :employees, Integer

#employer_identification_numberString?

Employer Identification Number (EIN) or equivalent.

Returns:

  • (String, nil)


316
# File 'lib/dataleon/models/company_registration.rb', line 316

optional :employer_identification_number, String

#insolvency_existsBoolean?

Indicates whether an insolvency procedure exists for the company.

Returns:

  • (Boolean, nil)


322
# File 'lib/dataleon/models/company_registration.rb', line 322

optional :insolvency_exists, Dataleon::Internal::Type::Boolean

#insolvency_ongoingBoolean?

Indicates whether an insolvency procedure is ongoing for the company.

Returns:

  • (Boolean, nil)


328
# File 'lib/dataleon/models/company_registration.rb', line 328

optional :insolvency_ongoing, Dataleon::Internal::Type::Boolean

Legal form or structure of the company (e.g., LLC, SARL).

Returns:

  • (String, nil)


334
# File 'lib/dataleon/models/company_registration.rb', line 334

optional :legal_form, String

#nameString?

Legal registered name of the company.

Returns:

  • (String, nil)


340
# File 'lib/dataleon/models/company_registration.rb', line 340

optional :name, String

#phone_numberString?

Contact phone number for the company, including country code.

Returns:

  • (String, nil)


346
# File 'lib/dataleon/models/company_registration.rb', line 346

optional :phone_number, String

#registration_dateDate?

Date when the company was officially registered.

Returns:

  • (Date, nil)


352
# File 'lib/dataleon/models/company_registration.rb', line 352

optional :registration_date, Date

#registration_idString?

Official company registration number or ID.

Returns:

  • (String, nil)


358
# File 'lib/dataleon/models/company_registration.rb', line 358

optional :registration_id, String

#share_capitalString?

Total share capital of the company, including currency.

Returns:

  • (String, nil)


364
# File 'lib/dataleon/models/company_registration.rb', line 364

optional :share_capital, String

#statusString?

Current status of the company (e.g., active, inactive).

Returns:

  • (String, nil)


370
# File 'lib/dataleon/models/company_registration.rb', line 370

optional :status, String

#tax_identification_numberString?

Tax identification number for the company.

Returns:

  • (String, nil)


376
# File 'lib/dataleon/models/company_registration.rb', line 376

optional :tax_identification_number, String

#typeString?

Type of company within the workspace, e.g., main or affiliated.

Returns:

  • (String, nil)


382
# File 'lib/dataleon/models/company_registration.rb', line 382

optional :type, String

#website_urlString?

Official website URL of the company.

Returns:

  • (String, nil)


388
# File 'lib/dataleon/models/company_registration.rb', line 388

optional :website_url, String