Class: Dataleon::Models::CompanyUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dataleon::Models::CompanyUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/dataleon/models/company_update_params.rb
Overview
Defined Under Namespace
Classes: Company, TechnicalData
Instance Attribute Summary collapse
-
#company ⇒ Dataleon::Models::CompanyUpdateParams::Company
Main information about the company being registered.
- #company_id ⇒ String
-
#source_id ⇒ String?
Optional identifier to track the origin of the request or integration from your system.
-
#technical_data ⇒ Dataleon::Models::CompanyUpdateParams::TechnicalData?
Technical metadata and callback configuration.
-
#workspace_id ⇒ String
Unique identifier of the workspace in which the company is being created.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(name:, address: nil, commercial_name: nil, country: nil, email: nil, employer_identification_number: nil, legal_form: nil, phone_number: nil, registration_date: nil, registration_id: nil, share_capital: nil, status: nil, tax_identification_number: nil, type: nil, website_url: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Company for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, address: nil, commercial_name: nil, country: nil, email: nil, employer_identification_number: nil, legal_form: nil, phone_number: nil, registration_date: nil, registration_id: nil, share_capital: nil, status: nil, tax_identification_number: nil, type: nil, website_url: nil) ⇒ Object
Some parameter documentations has been truncated, see Company for more details.
Main information about the company being registered.
|
|
# File 'lib/dataleon/models/company_update_params.rb', line 147
|
Instance Attribute Details
#company ⇒ Dataleon::Models::CompanyUpdateParams::Company
Main information about the company being registered.
19 |
# File 'lib/dataleon/models/company_update_params.rb', line 19 required :company, -> { Dataleon::CompanyUpdateParams::Company } |
#company_id ⇒ String
13 |
# File 'lib/dataleon/models/company_update_params.rb', line 13 required :company_id, String |
#source_id ⇒ String?
Optional identifier to track the origin of the request or integration from your system.
32 |
# File 'lib/dataleon/models/company_update_params.rb', line 32 optional :source_id, String |
#technical_data ⇒ Dataleon::Models::CompanyUpdateParams::TechnicalData?
Technical metadata and callback configuration.
38 |
# File 'lib/dataleon/models/company_update_params.rb', line 38 optional :technical_data, -> { Dataleon::CompanyUpdateParams::TechnicalData } |
#workspace_id ⇒ String
Unique identifier of the workspace in which the company is being created.
25 |
# File 'lib/dataleon/models/company_update_params.rb', line 25 required :workspace_id, String |