Class: Dataleon::Models::CompanyUpdateParams::Company

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dataleon/models/company_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(company_id:, company:, workspace_id:, source_id: nil, technical_data: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Dataleon::Models::CompanyUpdateParams for more details.

Parameters:



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/dataleon/models/company_update_params.rb', line 56

class Company < Dataleon::Internal::Type::BaseModel
  # @!attribute name
  #   Legal name of the company.
  #
  #   @return [String]
  required :name, String

  # @!attribute address
  #   Registered address of the company.
  #
  #   @return [String, nil]
  optional :address, String

  # @!attribute commercial_name
  #   Commercial or trade name of the company, if different from the legal name.
  #
  #   @return [String, nil]
  optional :commercial_name, String

  # @!attribute country
  #   ISO 3166-1 alpha-2 country code of company registration (e.g., "FR" for France).
  #
  #   @return [String, nil]
  optional :country, String

  # @!attribute email
  #   Contact email address for the company.
  #
  #   @return [String, nil]
  optional :email, String

  # @!attribute employer_identification_number
  #   Employer Identification Number (EIN) or equivalent.
  #
  #   @return [String, nil]
  optional :employer_identification_number, String

  # @!attribute legal_form
  #   Legal structure of the company (e.g., SARL, SAS).
  #
  #   @return [String, nil]
  optional :legal_form, String

  # @!attribute phone_number
  #   Contact phone number for the company.
  #
  #   @return [String, nil]
  optional :phone_number, String

  # @!attribute registration_date
  #   Date of official company registration in YYYY-MM-DD format.
  #
  #   @return [String, nil]
  optional :registration_date, String

  # @!attribute registration_id
  #   Official company registration identifier.
  #
  #   @return [String, nil]
  optional :registration_id, String

  # @!attribute share_capital
  #   Declared share capital of the company, usually in euros.
  #
  #   @return [String, nil]
  optional :share_capital, String

  # @!attribute status
  #   Current status of the company (e.g., active, inactive).
  #
  #   @return [String, nil]
  optional :status, String

  # @!attribute tax_identification_number
  #   National tax identifier (e.g., VAT or TIN).
  #
  #   @return [String, nil]
  optional :tax_identification_number, String

  # @!attribute type
  #   Type of company, such as "main" or "affiliated".
  #
  #   @return [String, nil]
  optional :type, String

  # @!attribute website_url
  #   Company’s official website URL.
  #
  #   @return [String, nil]
  optional :website_url, String

  # @!method initialize(name:, address: nil, commercial_name: nil, country: nil, email: nil, employer_identification_number: nil, legal_form: nil, phone_number: nil, registration_date: nil, registration_id: nil, share_capital: nil, status: nil, tax_identification_number: nil, type: nil, website_url: nil)
  #   Some parameter documentations has been truncated, see
  #   {Dataleon::Models::CompanyUpdateParams::Company} for more details.
  #
  #   Main information about the company being registered.
  #
  #   @param name [String] Legal name of the company.
  #
  #   @param address [String] Registered address of the company.
  #
  #   @param commercial_name [String] Commercial or trade name of the company, if different from the legal name.
  #
  #   @param country [String] ISO 3166-1 alpha-2 country code of company registration (e.g., "FR" for France).
  #
  #   @param email [String] Contact email address for the company.
  #
  #   @param employer_identification_number [String] Employer Identification Number (EIN) or equivalent.
  #
  #   @param legal_form [String] Legal structure of the company (e.g., SARL, SAS).
  #
  #   @param phone_number [String] Contact phone number for the company.
  #
  #   @param registration_date [String] Date of official company registration in YYYY-MM-DD format.
  #
  #   @param registration_id [String] Official company registration identifier.
  #
  #   @param share_capital [String] Declared share capital of the company, usually in euros.
  #
  #   @param status [String] Current status of the company (e.g., active, inactive).
  #
  #   @param tax_identification_number [String] National tax identifier (e.g., VAT or TIN).
  #
  #   @param type [String] Type of company, such as "main" or "affiliated".
  #
  #   @param website_url [String] Company’s official website URL.
end

Instance Attribute Details

#addressString?

Registered address of the company.

Returns:

  • (String, nil)


67
# File 'lib/dataleon/models/company_update_params.rb', line 67

optional :address, String

#commercial_nameString?

Commercial or trade name of the company, if different from the legal name.

Returns:

  • (String, nil)


73
# File 'lib/dataleon/models/company_update_params.rb', line 73

optional :commercial_name, String

#countryString?

ISO 3166-1 alpha-2 country code of company registration (e.g., “FR” for France).

Returns:

  • (String, nil)


79
# File 'lib/dataleon/models/company_update_params.rb', line 79

optional :country, String

#emailString?

Contact email address for the company.

Returns:

  • (String, nil)


85
# File 'lib/dataleon/models/company_update_params.rb', line 85

optional :email, String

#employer_identification_numberString?

Employer Identification Number (EIN) or equivalent.

Returns:

  • (String, nil)


91
# File 'lib/dataleon/models/company_update_params.rb', line 91

optional :employer_identification_number, String

Legal structure of the company (e.g., SARL, SAS).

Returns:

  • (String, nil)


97
# File 'lib/dataleon/models/company_update_params.rb', line 97

optional :legal_form, String

#nameString

Legal name of the company.

Returns:

  • (String)


61
# File 'lib/dataleon/models/company_update_params.rb', line 61

required :name, String

#phone_numberString?

Contact phone number for the company.

Returns:

  • (String, nil)


103
# File 'lib/dataleon/models/company_update_params.rb', line 103

optional :phone_number, String

#registration_dateString?

Date of official company registration in YYYY-MM-DD format.

Returns:

  • (String, nil)


109
# File 'lib/dataleon/models/company_update_params.rb', line 109

optional :registration_date, String

#registration_idString?

Official company registration identifier.

Returns:

  • (String, nil)


115
# File 'lib/dataleon/models/company_update_params.rb', line 115

optional :registration_id, String

#share_capitalString?

Declared share capital of the company, usually in euros.

Returns:

  • (String, nil)


121
# File 'lib/dataleon/models/company_update_params.rb', line 121

optional :share_capital, String

#statusString?

Current status of the company (e.g., active, inactive).

Returns:

  • (String, nil)


127
# File 'lib/dataleon/models/company_update_params.rb', line 127

optional :status, String

#tax_identification_numberString?

National tax identifier (e.g., VAT or TIN).

Returns:

  • (String, nil)


133
# File 'lib/dataleon/models/company_update_params.rb', line 133

optional :tax_identification_number, String

#typeString?

Type of company, such as “main” or “affiliated”.

Returns:

  • (String, nil)


139
# File 'lib/dataleon/models/company_update_params.rb', line 139

optional :type, String

#website_urlString?

Company’s official website URL.

Returns:

  • (String, nil)


145
# File 'lib/dataleon/models/company_update_params.rb', line 145

optional :website_url, String