Class: Dataleon::Models::Individual::Tag
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dataleon::Models::Individual::Tag
- Defined in:
- lib/dataleon/models/individual.rb
Instance Attribute Summary collapse
-
#key ⇒ String?
Name of the tag used to identify the metadata field.
-
#private ⇒ Boolean?
Indicates whether the tag is private (not visible to external users).
-
#type ⇒ String?
Data type of the tag value (e.g., “string”, “number”, “boolean”).
-
#value ⇒ String?
Value assigned to the tag.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Dataleon::Internal::Type::BaseModel
Instance Attribute Details
#key ⇒ String?
Name of the tag used to identify the metadata field.
609 |
# File 'lib/dataleon/models/individual.rb', line 609 optional :key, String |
#private ⇒ Boolean?
Indicates whether the tag is private (not visible to external users).
615 |
# File 'lib/dataleon/models/individual.rb', line 615 optional :private, Dataleon::Internal::Type::Boolean |
#type ⇒ String?
Data type of the tag value (e.g., “string”, “number”, “boolean”).
621 |
# File 'lib/dataleon/models/individual.rb', line 621 optional :type, String |
#value ⇒ String?
Value assigned to the tag.
627 |
# File 'lib/dataleon/models/individual.rb', line 627 optional :value, String |