Class: Dataleon::Models::IndividualCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dataleon::Models::IndividualCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/dataleon/models/individual_create_params.rb
Overview
Defined Under Namespace
Classes: Person, TechnicalData
Instance Attribute Summary collapse
-
#person ⇒ Dataleon::Models::IndividualCreateParams::Person?
Personal information about the individual.
-
#source_id ⇒ String?
Optional identifier for tracking the source system or integration from your system.
-
#technical_data ⇒ Dataleon::Models::IndividualCreateParams::TechnicalData?
Technical metadata related to the request or processing.
-
#workspace_id ⇒ String
Unique identifier of the workspace where the individual is being registered.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Dataleon::Internal::Type::BaseModel
Instance Attribute Details
#person ⇒ Dataleon::Models::IndividualCreateParams::Person?
Personal information about the individual.
20 |
# File 'lib/dataleon/models/individual_create_params.rb', line 20 optional :person, -> { Dataleon::IndividualCreateParams::Person } |
#source_id ⇒ String?
Optional identifier for tracking the source system or integration from your system.
27 |
# File 'lib/dataleon/models/individual_create_params.rb', line 27 optional :source_id, String |
#technical_data ⇒ Dataleon::Models::IndividualCreateParams::TechnicalData?
Technical metadata related to the request or processing.
33 |
# File 'lib/dataleon/models/individual_create_params.rb', line 33 optional :technical_data, -> { Dataleon::IndividualCreateParams::TechnicalData } |
#workspace_id ⇒ String
Unique identifier of the workspace where the individual is being registered.
14 |
# File 'lib/dataleon/models/individual_create_params.rb', line 14 required :workspace_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/dataleon/models/individual_create_params.rb', line 126
|