Module: Dataleon::Models::IndividualCreateParams::TechnicalData::PortalStep

Extended by:
Internal::Type::Enum
Defined in:
lib/dataleon/models/individual_create_params.rb

Constant Summary collapse

IDENTITY_VERIFICATION =
:identity_verification
DOCUMENT_SIGNING =
:document_signing
PROOF_OF_ADDRESS =
:proof_of_address
SELFIE =
:selfie
FACE_MATCH =
:face_match

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/dataleon/models/individual_create_params.rb', line 206

Instance Method Details

#initialize(active_aml_suspicions: nil, callback_url: nil, callback_url_notification: nil, filtering_score_aml_suspicions: nil, language: nil, portal_steps: nil, raw_data: nil) ⇒ Object

Some parameter documentations has been truncated, see Dataleon::Models::IndividualCreateParams::TechnicalData for more details.

Technical metadata related to the request or processing.

Parameters:

  • active_aml_suspicions (Boolean) (defaults to: nil)

    Flag indicating whether there are active research AML (Anti-Money Laundering) su

  • callback_url (String) (defaults to: nil)

    URL to call back upon completion of processing.

  • callback_url_notification (String) (defaults to: nil)

    URL for receive notifications about the processing state or status.

  • filtering_score_aml_suspicions (Float) (defaults to: nil)

    Minimum filtering score (between 0 and 1) for AML suspicions to be considered.

  • language (String) (defaults to: nil)

    Preferred language for communication (e.g., “eng”, “fra”).

  • portal_steps (Array<Symbol, Dataleon::Models::IndividualCreateParams::TechnicalData::PortalStep>) (defaults to: nil)

    List of steps to include in the portal workflow.

  • raw_data (Boolean) (defaults to: nil)

    Flag indicating whether to include raw data in the response.



197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/dataleon/models/individual_create_params.rb', line 197

module PortalStep
  extend Dataleon::Internal::Type::Enum

  IDENTITY_VERIFICATION = :identity_verification
  DOCUMENT_SIGNING = :document_signing
  PROOF_OF_ADDRESS = :proof_of_address
  SELFIE = :selfie
  FACE_MATCH = :face_match

  # @!method self.values
  #   @return [Array<Symbol>]
end