Class: Dataleon::Models::IndividualUpdateParams::TechnicalData

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dataleon/models/individual_update_params.rb

Defined Under Namespace

Modules: PortalStep

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Dataleon::Internal::Type::BaseModel

Instance Attribute Details

#active_aml_suspicionsBoolean?

Flag indicating whether there are active research AML (Anti-Money Laundering) suspicions for the individual when you apply for a new entry or get an existing one.

Returns:

  • (Boolean, nil)


145
# File 'lib/dataleon/models/individual_update_params.rb', line 145

optional :active_aml_suspicions, Dataleon::Internal::Type::Boolean

#callback_urlString?

URL to call back upon completion of processing.

Returns:

  • (String, nil)


151
# File 'lib/dataleon/models/individual_update_params.rb', line 151

optional :callback_url, String

#callback_url_notificationString?

URL for receive notifications about the processing state or status.

Returns:

  • (String, nil)


157
# File 'lib/dataleon/models/individual_update_params.rb', line 157

optional :callback_url_notification, String

#filtering_score_aml_suspicionsFloat?

Minimum filtering score (between 0 and 1) for AML suspicions to be considered.

Returns:

  • (Float, nil)


163
# File 'lib/dataleon/models/individual_update_params.rb', line 163

optional :filtering_score_aml_suspicions, Float

#languageString?

Preferred language for communication (e.g., “eng”, “fra”).

Returns:

  • (String, nil)


169
# File 'lib/dataleon/models/individual_update_params.rb', line 169

optional :language, String

#portal_stepsArray<Symbol, Dataleon::Models::IndividualUpdateParams::TechnicalData::PortalStep>?

List of steps to include in the portal workflow.



175
176
# File 'lib/dataleon/models/individual_update_params.rb', line 175

optional :portal_steps,
-> { Dataleon::Internal::Type::ArrayOf[enum: Dataleon::IndividualUpdateParams::TechnicalData::PortalStep] }

#raw_dataBoolean?

Flag indicating whether to include raw data in the response.

Returns:

  • (Boolean, nil)


182
# File 'lib/dataleon/models/individual_update_params.rb', line 182

optional :raw_data, Dataleon::Internal::Type::Boolean