Class: Dataleon::Models::Individuals::GenericDocument::Value

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/dataleon/models/individuals/generic_document.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(confidence: nil, name: nil, value: nil) ⇒ Object

Parameters:

  • confidence (Float) (defaults to: nil)

    Confidence score (between 0 and 1) for the extracted value.

  • name (String) (defaults to: nil)

    Name or label of the extracted field.

  • value (Array<Integer>) (defaults to: nil)

    List of integer values related to the field (e.g., bounding box coordinates).



# File 'lib/dataleon/models/individuals/generic_document.rb', line 122

Instance Attribute Details

#confidenceFloat?

Confidence score (between 0 and 1) for the extracted value.

Returns:

  • (Float, nil)


108
# File 'lib/dataleon/models/individuals/generic_document.rb', line 108

optional :confidence, Float

#nameString?

Name or label of the extracted field.

Returns:

  • (String, nil)


114
# File 'lib/dataleon/models/individuals/generic_document.rb', line 114

optional :name, String

#valueArray<Integer>?

List of integer values related to the field (e.g., bounding box coordinates).

Returns:

  • (Array<Integer>, nil)


120
# File 'lib/dataleon/models/individuals/generic_document.rb', line 120

optional :value, Dataleon::Internal::Type::ArrayOf[Integer]