Class: Dataleon::Models::Check
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dataleon::Models::Check
- Defined in:
- lib/dataleon/models/check.rb
Instance Attribute Summary collapse
-
#masked ⇒ Boolean?
Indicates whether the result or data is masked/hidden.
-
#message ⇒ String?
Additional message or explanation about the check result.
-
#name ⇒ String?
Name or type of the check performed.
-
#validate ⇒ Boolean?
Result of the check, true if passed.
-
#weight ⇒ Integer?
Importance or weight of the check, often used in scoring.
Instance Method Summary collapse
-
#initialize(masked: nil, message: nil, name: nil, validate: nil, weight: nil) ⇒ Object
constructor
Represents a verification check result.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(masked: nil, message: nil, name: nil, validate: nil, weight: nil) ⇒ Object
Represents a verification check result.
|
|
# File 'lib/dataleon/models/check.rb', line 36
|
Instance Attribute Details
#masked ⇒ Boolean?
Indicates whether the result or data is masked/hidden.
10 |
# File 'lib/dataleon/models/check.rb', line 10 optional :masked, Dataleon::Internal::Type::Boolean |
#message ⇒ String?
Additional message or explanation about the check result.
16 |
# File 'lib/dataleon/models/check.rb', line 16 optional :message, String |
#name ⇒ String?
Name or type of the check performed.
22 |
# File 'lib/dataleon/models/check.rb', line 22 optional :name, String |
#validate ⇒ Boolean?
Result of the check, true if passed.
28 |
# File 'lib/dataleon/models/check.rb', line 28 optional :validate, Dataleon::Internal::Type::Boolean |
#weight ⇒ Integer?
Importance or weight of the check, often used in scoring.
34 |
# File 'lib/dataleon/models/check.rb', line 34 optional :weight, Integer |