Class: Dataleon::Models::CompanyCreateParams::Company
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dataleon::Models::CompanyCreateParams::Company
- Defined in:
- lib/dataleon/models/company_create_params.rb
Instance Attribute Summary collapse
-
#address ⇒ String?
Registered address of the company.
-
#commercial_name ⇒ String?
Commercial or trade name of the company, if different from the legal name.
-
#country ⇒ String?
ISO 3166-1 alpha-2 country code of company registration (e.g., “FR” for France).
-
#email ⇒ String?
Contact email address for the company.
-
#employer_identification_number ⇒ String?
Employer Identification Number (EIN) or equivalent.
-
#legal_form ⇒ String?
Legal structure of the company (e.g., SARL, SAS).
-
#name ⇒ String
Legal name of the company.
-
#phone_number ⇒ String?
Contact phone number for the company.
-
#registration_date ⇒ String?
Date of official company registration in YYYY-MM-DD format.
-
#registration_id ⇒ String?
Official company registration identifier.
-
#share_capital ⇒ String?
Declared share capital of the company, usually in euros.
-
#status ⇒ String?
Current status of the company (e.g., active, inactive).
-
#tax_identification_number ⇒ String?
National tax identifier (e.g., VAT or TIN).
-
#type ⇒ String?
Type of company, such as “main” or “affiliated”.
-
#website_url ⇒ String?
Company’s official website URL.
Instance Method Summary collapse
-
#initialize(company:, workspace_id:, source_id: nil, technical_data: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see Dataleon::Models::CompanyCreateParams for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company:, workspace_id:, source_id: nil, technical_data: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Dataleon::Models::CompanyCreateParams for more details.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/dataleon/models/company_create_params.rb', line 49 class Company < Dataleon::Internal::Type::BaseModel # @!attribute name # Legal name of the company. # # @return [String] required :name, String # @!attribute address # Registered address of the company. # # @return [String, nil] optional :address, String # @!attribute commercial_name # Commercial or trade name of the company, if different from the legal name. # # @return [String, nil] optional :commercial_name, String # @!attribute country # ISO 3166-1 alpha-2 country code of company registration (e.g., "FR" for France). # # @return [String, nil] optional :country, String # @!attribute email # Contact email address for the company. # # @return [String, nil] optional :email, String # @!attribute employer_identification_number # Employer Identification Number (EIN) or equivalent. # # @return [String, nil] optional :employer_identification_number, String # @!attribute legal_form # Legal structure of the company (e.g., SARL, SAS). # # @return [String, nil] optional :legal_form, String # @!attribute phone_number # Contact phone number for the company. # # @return [String, nil] optional :phone_number, String # @!attribute registration_date # Date of official company registration in YYYY-MM-DD format. # # @return [String, nil] optional :registration_date, String # @!attribute registration_id # Official company registration identifier. # # @return [String, nil] optional :registration_id, String # @!attribute share_capital # Declared share capital of the company, usually in euros. # # @return [String, nil] optional :share_capital, String # @!attribute status # Current status of the company (e.g., active, inactive). # # @return [String, nil] optional :status, String # @!attribute tax_identification_number # National tax identifier (e.g., VAT or TIN). # # @return [String, nil] optional :tax_identification_number, String # @!attribute type # Type of company, such as "main" or "affiliated". # # @return [String, nil] optional :type, String # @!attribute website_url # Company’s official website URL. # # @return [String, nil] optional :website_url, String # @!method initialize(name:, address: nil, commercial_name: nil, country: nil, email: nil, employer_identification_number: nil, legal_form: nil, phone_number: nil, registration_date: nil, registration_id: nil, share_capital: nil, status: nil, tax_identification_number: nil, type: nil, website_url: nil) # Some parameter documentations has been truncated, see # {Dataleon::Models::CompanyCreateParams::Company} for more details. # # Main information about the company being registered. # # @param name [String] Legal name of the company. # # @param address [String] Registered address of the company. # # @param commercial_name [String] Commercial or trade name of the company, if different from the legal name. # # @param country [String] ISO 3166-1 alpha-2 country code of company registration (e.g., "FR" for France). # # @param email [String] Contact email address for the company. # # @param employer_identification_number [String] Employer Identification Number (EIN) or equivalent. # # @param legal_form [String] Legal structure of the company (e.g., SARL, SAS). # # @param phone_number [String] Contact phone number for the company. # # @param registration_date [String] Date of official company registration in YYYY-MM-DD format. # # @param registration_id [String] Official company registration identifier. # # @param share_capital [String] Declared share capital of the company, usually in euros. # # @param status [String] Current status of the company (e.g., active, inactive). # # @param tax_identification_number [String] National tax identifier (e.g., VAT or TIN). # # @param type [String] Type of company, such as "main" or "affiliated". # # @param website_url [String] Company’s official website URL. end |
Instance Attribute Details
#address ⇒ String?
Registered address of the company.
60 |
# File 'lib/dataleon/models/company_create_params.rb', line 60 optional :address, String |
#commercial_name ⇒ String?
Commercial or trade name of the company, if different from the legal name.
66 |
# File 'lib/dataleon/models/company_create_params.rb', line 66 optional :commercial_name, String |
#country ⇒ String?
ISO 3166-1 alpha-2 country code of company registration (e.g., “FR” for France).
72 |
# File 'lib/dataleon/models/company_create_params.rb', line 72 optional :country, String |
#email ⇒ String?
Contact email address for the company.
78 |
# File 'lib/dataleon/models/company_create_params.rb', line 78 optional :email, String |
#employer_identification_number ⇒ String?
Employer Identification Number (EIN) or equivalent.
84 |
# File 'lib/dataleon/models/company_create_params.rb', line 84 optional :employer_identification_number, String |
#legal_form ⇒ String?
Legal structure of the company (e.g., SARL, SAS).
90 |
# File 'lib/dataleon/models/company_create_params.rb', line 90 optional :legal_form, String |
#name ⇒ String
Legal name of the company.
54 |
# File 'lib/dataleon/models/company_create_params.rb', line 54 required :name, String |
#phone_number ⇒ String?
Contact phone number for the company.
96 |
# File 'lib/dataleon/models/company_create_params.rb', line 96 optional :phone_number, String |
#registration_date ⇒ String?
Date of official company registration in YYYY-MM-DD format.
102 |
# File 'lib/dataleon/models/company_create_params.rb', line 102 optional :registration_date, String |
#registration_id ⇒ String?
Official company registration identifier.
108 |
# File 'lib/dataleon/models/company_create_params.rb', line 108 optional :registration_id, String |
#share_capital ⇒ String?
Declared share capital of the company, usually in euros.
114 |
# File 'lib/dataleon/models/company_create_params.rb', line 114 optional :share_capital, String |
#status ⇒ String?
Current status of the company (e.g., active, inactive).
120 |
# File 'lib/dataleon/models/company_create_params.rb', line 120 optional :status, String |
#tax_identification_number ⇒ String?
National tax identifier (e.g., VAT or TIN).
126 |
# File 'lib/dataleon/models/company_create_params.rb', line 126 optional :tax_identification_number, String |
#type ⇒ String?
Type of company, such as “main” or “affiliated”.
132 |
# File 'lib/dataleon/models/company_create_params.rb', line 132 optional :type, String |
#website_url ⇒ String?
Company’s official website URL.
138 |
# File 'lib/dataleon/models/company_create_params.rb', line 138 optional :website_url, String |