Class: Dataleon::Models::CompanyCreateParams::TechnicalData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dataleon::Models::CompanyCreateParams::TechnicalData
- Defined in:
- lib/dataleon/models/company_create_params.rb
Defined Under Namespace
Modules: PortalStep
Instance Attribute Summary collapse
-
#active_aml_suspicions ⇒ Boolean?
Flag indicating whether there are active research AML (Anti-Money Laundering) suspicions for the company when you apply for a new entry or get an existing one.
-
#callback_url ⇒ String?
URL to receive a callback once the company is processed.
-
#callback_url_notification ⇒ String?
URL to receive notifications about the processing state and status.
-
#filtering_score_aml_suspicions ⇒ Float?
Minimum filtering score (between 0 and 1) for AML suspicions to be considered.
-
#language ⇒ String?
Preferred language for responses or notifications (e.g., “eng”, “fra”).
-
#portal_steps ⇒ Array<Symbol, Dataleon::Models::CompanyCreateParams::TechnicalData::PortalStep>?
List of steps to include in the portal workflow.
-
#raw_data ⇒ Boolean?
Flag indicating whether to include raw data in the response.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Dataleon::Internal::Type::BaseModel
Instance Attribute Details
#active_aml_suspicions ⇒ Boolean?
Flag indicating whether there are active research AML (Anti-Money Laundering) suspicions for the company when you apply for a new entry or get an existing one.
184 |
# File 'lib/dataleon/models/company_create_params.rb', line 184 optional :active_aml_suspicions, Dataleon::Internal::Type::Boolean |
#callback_url ⇒ String?
URL to receive a callback once the company is processed.
190 |
# File 'lib/dataleon/models/company_create_params.rb', line 190 optional :callback_url, String |
#callback_url_notification ⇒ String?
URL to receive notifications about the processing state and status.
196 |
# File 'lib/dataleon/models/company_create_params.rb', line 196 optional :callback_url_notification, String |
#filtering_score_aml_suspicions ⇒ Float?
Minimum filtering score (between 0 and 1) for AML suspicions to be considered.
202 |
# File 'lib/dataleon/models/company_create_params.rb', line 202 optional :filtering_score_aml_suspicions, Float |
#language ⇒ String?
Preferred language for responses or notifications (e.g., “eng”, “fra”).
208 |
# File 'lib/dataleon/models/company_create_params.rb', line 208 optional :language, String |
#portal_steps ⇒ Array<Symbol, Dataleon::Models::CompanyCreateParams::TechnicalData::PortalStep>?
List of steps to include in the portal workflow.
214 215 |
# File 'lib/dataleon/models/company_create_params.rb', line 214 optional :portal_steps, -> { Dataleon::Internal::Type::ArrayOf[enum: Dataleon::CompanyCreateParams::TechnicalData::PortalStep] } |