Class: Dataleon::Models::Individual::Person
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dataleon::Models::Individual::Person
- Defined in:
- lib/dataleon/models/individual.rb
Overview
Instance Attribute Summary collapse
-
#birthday ⇒ String?
Date of birth, formatted as DD/MM/YYYY.
-
#email ⇒ String?
Email address of the individual.
-
#face_image_signed_url ⇒ String?
Signed URL linking to the person’s face image.
-
#first_name ⇒ String?
First (given) name of the person.
-
#full_name ⇒ String?
Full name of the person, typically concatenation of first and last names.
-
#gender ⇒ String?
Gender of the individual (e.g., “M” for male, “F” for female).
-
#last_name ⇒ String?
Last (family) name of the person.
-
#maiden_name ⇒ String?
Maiden name of the person, if applicable.
-
#nationality ⇒ String?
Nationality of the individual (ISO 3166-1 alpha-3 country code).
-
#phone_number ⇒ String?
Contact phone number including country code.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Dataleon::Internal::Type::BaseModel
Instance Attribute Details
#birthday ⇒ String?
Date of birth, formatted as DD/MM/YYYY.
464 |
# File 'lib/dataleon/models/individual.rb', line 464 optional :birthday, String |
#email ⇒ String?
Email address of the individual.
470 |
# File 'lib/dataleon/models/individual.rb', line 470 optional :email, String |
#face_image_signed_url ⇒ String?
Signed URL linking to the person’s face image.
476 |
# File 'lib/dataleon/models/individual.rb', line 476 optional :face_image_signed_url, String |
#first_name ⇒ String?
First (given) name of the person.
482 |
# File 'lib/dataleon/models/individual.rb', line 482 optional :first_name, String |
#full_name ⇒ String?
Full name of the person, typically concatenation of first and last names.
488 |
# File 'lib/dataleon/models/individual.rb', line 488 optional :full_name, String |
#gender ⇒ String?
Gender of the individual (e.g., “M” for male, “F” for female).
494 |
# File 'lib/dataleon/models/individual.rb', line 494 optional :gender, String |
#last_name ⇒ String?
Last (family) name of the person.
500 |
# File 'lib/dataleon/models/individual.rb', line 500 optional :last_name, String |
#maiden_name ⇒ String?
Maiden name of the person, if applicable.
506 |
# File 'lib/dataleon/models/individual.rb', line 506 optional :maiden_name, String |
#nationality ⇒ String?
Nationality of the individual (ISO 3166-1 alpha-3 country code).
512 |
# File 'lib/dataleon/models/individual.rb', line 512 optional :nationality, String |
#phone_number ⇒ String?
Contact phone number including country code.
518 |
# File 'lib/dataleon/models/individual.rb', line 518 optional :phone_number, String |