Class: Dataleon::Models::IndividualUpdateParams::TechnicalData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dataleon::Models::IndividualUpdateParams::TechnicalData
- Defined in:
- lib/dataleon/models/individual_update_params.rb
Defined Under Namespace
Modules: PortalStep
Instance Attribute Summary collapse
-
#active_aml_suspicions ⇒ Boolean?
Flag indicating whether there are active research AML (Anti-Money Laundering) suspicions for the individual when you apply for a new entry or get an existing one.
-
#callback_url ⇒ String?
URL to call back upon completion of processing.
-
#callback_url_notification ⇒ String?
URL for receive notifications about the processing state or status.
-
#filtering_score_aml_suspicions ⇒ Float?
Minimum filtering score (between 0 and 1) for AML suspicions to be considered.
-
#language ⇒ String?
Preferred language for communication (e.g., “eng”, “fra”).
-
#portal_steps ⇒ Array<Symbol, Dataleon::Models::IndividualUpdateParams::TechnicalData::PortalStep>?
List of steps to include in the portal workflow.
-
#raw_data ⇒ Boolean?
Flag indicating whether to include raw data in the response.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Dataleon::Internal::Type::BaseModel
Instance Attribute Details
#active_aml_suspicions ⇒ Boolean?
Flag indicating whether there are active research AML (Anti-Money Laundering) suspicions for the individual when you apply for a new entry or get an existing one.
145 |
# File 'lib/dataleon/models/individual_update_params.rb', line 145 optional :active_aml_suspicions, Dataleon::Internal::Type::Boolean |
#callback_url ⇒ String?
URL to call back upon completion of processing.
151 |
# File 'lib/dataleon/models/individual_update_params.rb', line 151 optional :callback_url, String |
#callback_url_notification ⇒ String?
URL for receive notifications about the processing state or status.
157 |
# File 'lib/dataleon/models/individual_update_params.rb', line 157 optional :callback_url_notification, String |
#filtering_score_aml_suspicions ⇒ Float?
Minimum filtering score (between 0 and 1) for AML suspicions to be considered.
163 |
# File 'lib/dataleon/models/individual_update_params.rb', line 163 optional :filtering_score_aml_suspicions, Float |
#language ⇒ String?
Preferred language for communication (e.g., “eng”, “fra”).
169 |
# File 'lib/dataleon/models/individual_update_params.rb', line 169 optional :language, String |
#portal_steps ⇒ Array<Symbol, Dataleon::Models::IndividualUpdateParams::TechnicalData::PortalStep>?
List of steps to include in the portal workflow.
175 176 |
# File 'lib/dataleon/models/individual_update_params.rb', line 175 optional :portal_steps, -> { Dataleon::Internal::Type::ArrayOf[enum: Dataleon::IndividualUpdateParams::TechnicalData::PortalStep] } |