Class: Dataleon::Models::Individuals::DocumentResponse::Document
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dataleon::Models::Individuals::DocumentResponse::Document
- Defined in:
- lib/dataleon/models/individuals/document_response.rb
Instance Attribute Summary collapse
-
#document_type ⇒ String?
Functional type of the document (e.g., identity document, invoice).
-
#filename ⇒ String?
Original filename of the uploaded document.
-
#id ⇒ String?
Unique identifier of the document.
-
#name ⇒ String?
Human-readable name of the document.
-
#signed_url ⇒ String?
Secure URL to access the document.
-
#state ⇒ String?
Processing state of the document (e.g., WAITING, STARTED, RUNNING, PROCESSED).
-
#status ⇒ String?
Validation status of the document (e.g., need_review, approved, rejected).
-
#workspace_id ⇒ String?
Identifier of the workspace to which the document belongs.
Instance Method Summary collapse
-
#initialize(id: nil, document_type: nil, filename: nil, name: nil, signed_url: nil, state: nil, status: nil, workspace_id: nil) ⇒ Object
constructor
Represents a document stored and processed by the system, such as an identity card or a PDF contract.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, document_type: nil, filename: nil, name: nil, signed_url: nil, state: nil, status: nil, workspace_id: nil) ⇒ Object
Represents a document stored and processed by the system, such as an identity card or a PDF contract.
26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/dataleon/models/individuals/document_response.rb', line 26 class Document < Dataleon::Internal::Type::BaseModel # @!attribute id # Unique identifier of the document. # # @return [String, nil] optional :id, String # @!attribute document_type # Functional type of the document (e.g., identity document, invoice). # # @return [String, nil] optional :document_type, String # @!attribute filename # Original filename of the uploaded document. # # @return [String, nil] optional :filename, String # @!attribute name # Human-readable name of the document. # # @return [String, nil] optional :name, String # @!attribute signed_url # Secure URL to access the document. # # @return [String, nil] optional :signed_url, String # @!attribute state # Processing state of the document (e.g., WAITING, STARTED, RUNNING, PROCESSED). # # @return [String, nil] optional :state, String # @!attribute status # Validation status of the document (e.g., need_review, approved, rejected). # # @return [String, nil] optional :status, String # @!attribute workspace_id # Identifier of the workspace to which the document belongs. # # @return [String, nil] optional :workspace_id, String # @!method initialize(id: nil, document_type: nil, filename: nil, name: nil, signed_url: nil, state: nil, status: nil, workspace_id: nil) # Represents a document stored and processed by the system, such as an identity # card or a PDF contract. # # @param id [String] Unique identifier of the document. # # @param document_type [String] Functional type of the document (e.g., identity document, invoice). # # @param filename [String] Original filename of the uploaded document. # # @param name [String] Human-readable name of the document. # # @param signed_url [String] Secure URL to access the document. # # @param state [String] Processing state of the document (e.g., WAITING, STARTED, RUNNING, PROCESSED). # # @param status [String] Validation status of the document (e.g., need_review, approved, rejected). # # @param workspace_id [String] Identifier of the workspace to which the document belongs. end |
Instance Attribute Details
#document_type ⇒ String?
Functional type of the document (e.g., identity document, invoice).
37 |
# File 'lib/dataleon/models/individuals/document_response.rb', line 37 optional :document_type, String |
#filename ⇒ String?
Original filename of the uploaded document.
43 |
# File 'lib/dataleon/models/individuals/document_response.rb', line 43 optional :filename, String |
#id ⇒ String?
Unique identifier of the document.
31 |
# File 'lib/dataleon/models/individuals/document_response.rb', line 31 optional :id, String |
#name ⇒ String?
Human-readable name of the document.
49 |
# File 'lib/dataleon/models/individuals/document_response.rb', line 49 optional :name, String |
#signed_url ⇒ String?
Secure URL to access the document.
55 |
# File 'lib/dataleon/models/individuals/document_response.rb', line 55 optional :signed_url, String |
#state ⇒ String?
Processing state of the document (e.g., WAITING, STARTED, RUNNING, PROCESSED).
61 |
# File 'lib/dataleon/models/individuals/document_response.rb', line 61 optional :state, String |
#status ⇒ String?
Validation status of the document (e.g., need_review, approved, rejected).
67 |
# File 'lib/dataleon/models/individuals/document_response.rb', line 67 optional :status, String |
#workspace_id ⇒ String?
Identifier of the workspace to which the document belongs.
73 |
# File 'lib/dataleon/models/individuals/document_response.rb', line 73 optional :workspace_id, String |