Class: Dataleon::Models::Individuals::GenericDocument::Table
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Dataleon::Models::Individuals::GenericDocument::Table
- Defined in:
- lib/dataleon/models/individuals/generic_document.rb
Instance Attribute Summary collapse
-
#operation ⇒ Array<Object>?
List of operations or actions associated with the table.
Instance Method Summary collapse
-
#initialize(id: nil, checks: nil, created_at: nil, document_type: nil, name: nil, signed_url: nil, state: nil, status: nil, tables: nil, values: nil) ⇒ Object
constructor
Represents a general document with metadata, verification checks, and extracted data.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, checks: nil, created_at: nil, document_type: nil, name: nil, signed_url: nil, state: nil, status: nil, tables: nil, values: nil) ⇒ Object
Represents a general document with metadata, verification checks, and extracted data.
92 93 94 95 96 97 98 99 100 101 |
# File 'lib/dataleon/models/individuals/generic_document.rb', line 92 class Table < Dataleon::Internal::Type::BaseModel # @!attribute operation # List of operations or actions associated with the table. # # @return [Array<Object>, nil] optional :operation, Dataleon::Internal::Type::ArrayOf[Dataleon::Internal::Type::Unknown] # @!method initialize(operation: nil) # @param operation [Array<Object>] List of operations or actions associated with the table. end |